@@ -1,6 +1,6 @@
 /* connection_commands.c
  *
- * $Id: connection_commands.c,v 1.21 2000/02/07 20:52:52 nisse Exp $
+ * $Id: connection_commands.c,v 1.23 2000/03/16 22:33:11 nisse Exp $
  */
 
 /* lsh, an implementation of the ssh protocol
@@ -183,7 +183,15 @@ do_line(struct line_handler **h,
 	      {
 		connection->peer_flags
 		  |= (PEER_SSH_DSS_KLUDGE | PEER_SERVICE_ACCEPT_KLUDGE
+		      | PEER_USERAUTH_REQUEST_KLUDGE | PEER_SEND_NO_DEBUG 
+		      | PEER_X11_OPEN_KLUDGE);
+	      }
+	    else if ( (swver_len >= 5) && !memcmp(swver, "2.1.0", 5) )
+	      {
+		connection->peer_flags
+		  |= (PEER_SSH_DSS_KLUDGE
 		      | PEER_USERAUTH_REQUEST_KLUDGE | PEER_SEND_NO_DEBUG);
+		verbose("ssh.com 2.1.0\n");
 	      }
 #endif	    
 	    
