@@ -2,7 +2,7 @@
  *
  *
  *
- * $Id: io.h,v 1.51 1999/12/07 00:37:25 nisse Exp $ */
+ * $Id: io.h,v 1.54 2000/02/07 20:53:50 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -27,6 +27,7 @@
 #define LSH_IO_H_INCLUDED
 
 #include "abstract_io.h"
+#include "command.h"
 #include "resource.h"
 #include "write_buffer.h"
 
@@ -42,16 +43,6 @@
 #undef GABA_DECLARE
 
 
-/* A closed function with a file descriptor as argument */
-/* GABA:
-   (class
-     (name fd_callback)
-     (vars
-       (f indirect-method void "int fd")))
-*/
-
-#define FD_CALLBACK(c, fd) ((c)->f(&(c), (fd)))
-
 /* Close callbacks are called with a reason as argument. */
 
 /* End of file while reading.
@@ -78,17 +69,17 @@
 
 #define CLOSE_CALLBACK(c, r) ((c)->f((c), (r)))
 
-/* The fd read callback is a closure, in order to support different
- * reading styles (buffered and consuming). */
+/* The fd io callback is a closure, in order to support different
+ * reading styles (buffered and consuming). Also used for writing. */
 
 /* GABA:
    (class
-     (name io_read_callback)
+     (name io_callback)
      (vars
-       (read method void "struct lsh_fd *fd")))
+       (f method void "struct lsh_fd *fd")))
 */
 
-#define IO_READ_CALLBACK(c, fd) ((c)->read((c), (fd)))
+#define IO_CALLBACK(c, fd) ((c)->f((c), (fd)))
 
 /* GABA:
    (class
@@ -98,6 +89,9 @@
        (next object lsh_fd)
        (fd simple int)
 
+       ;; (backend object io_backend)
+       ;; (next_closed object lsh_fd)
+       
        ; Used for raising i/o- and eof-exceptions.
        ; Also passed on to readers of the consuming type,
        ; which seems kind of bogus.
@@ -110,38 +104,30 @@
 
        ; Called before poll
        (prepare method void)
-       
+
        (want_read simple int)
        ; Called if poll indicates that data can be read. 
-       ;;(read method void)
-			    
-       (read object io_read_callback)
+       (read object io_callback)
 
        (want_write simple int)
        ; Called if poll indicates that data can be written.
-       (write method void)
+       (write object io_callback)
 
-       ; FIXME: really_close is an improper name. It is used to
-       ; mark the fd's write_buffer as closed.
-       (really_close method void))) */
-
-#define PREPARE_FD(fd) ((fd)->prepare((fd)))
-#define READ_FD(fd) IO_READ_CALLBACK((fd)->read, (fd))
-#define WRITE_FD(fd) ((fd)->write((fd)))
-#define REALLY_CLOSE_FD(fd) ((fd)->really_close((fd)))
-
-/* GABA:
-   (class
-     (name io_fd)
-     (super lsh_fd)
-     (vars
-       ; Reading 
-       ;;(read_buffer object read_buffer)
-       ;; (handler object read_handler)
-       ; Writing 
-       (write_buffer object write_buffer)))
+       ; FIXME: We could put write_buffer inside the write callback,
+       ; but it seems simpler to keep it here, as it is needed by the
+       ; prepare and write_close methods.
+       (write_buffer object write_buffer)
+       
+       ; Called to when fd is closed for writing.
+       (write_close method void)))
 */
 
+#define FD_PREPARE(fd) ((fd)->prepare(fd))
+#define FD_READ(fd) IO_CALLBACK((fd)->read, (fd))
+#define FD_WRITE(fd) IO_CALLBACK((fd)->write, (fd))
+#define FD_WRITE_CLOSE(fd) ((fd)->write_close(fd))
+
+
 /* Used for read handlers like read_line and read_packet that
  * processes a little data at a time, possibly replacing the handler
  * and leaving some data for the new one. */
@@ -149,13 +135,13 @@
 /* GABA:
    (class
      (name io_buffered_read)
-     (super io_read_callback)
+     (super io_callback)
      (vars
        (buffer_size . UINT32)
        (handler object read_handler)))
 */
 
-struct io_read_callback *
+struct io_callback *
 make_buffered_read(UINT32 buffer_size,
 		   struct read_handler *handler);
 
@@ -165,7 +151,7 @@ make_buffered_read(UINT32 buffer_size,
 /* GABA:
    (class
      (name io_consuming_read)
-     (super io_read_callback)
+     (super io_callback)
      (vars
        (query method UINT32)
        ; Returns the maximum number of octets that
@@ -190,43 +176,20 @@ void init_consuming_read(struct io_consuming_read *self,
        ; The port number here is always in host byte order
        (port . UINT32))) */
 
+/* Returned by listen */
 /* GABA:
    (class
-     (name fd_listen_callback)
+     (name listen_value)
      (vars
-       (f method void int "struct address_info *")))
-*/
-#define FD_LISTEN_CALLBACK(c, fd, a) ((c)->f((c), (fd), (a)))
-
-/* FIXME: Get rid of this class, and store the user callback inside
- * the io_read_callback. */
-
-/* GABA:
-   (class
-     (name listen_fd)
-     (super lsh_fd)
-     (vars
-       (callback object fd_listen_callback)))
+       (fd object lsh_fd)
+       (peer object address_info)))
 */
 
-/* GABA:
-   (class
-     (name connect_fd)
-     (super lsh_fd)
-     (vars
-       (callback object fd_callback)))
-*/
+struct listen_value *
+make_listen_value(struct lsh_fd *fd,
+		  struct address_info *peer);
 
-/* GABA:
-   (class
-     (name callback)
-     (vars
-       (f method void)))
-*/
-
-#define CALLBACK(c) ((c)->f(c))
-
-/* GABA:
+/* ;; GABA:
    (class
      (name callout)
      (vars
@@ -235,23 +198,16 @@ void init_consuming_read(struct io_consuming_read *self,
        (when . time_t)))
 */
 
-#if 0
-struct callout
-{
-  struct lsh_object header;
-  
-  struct callout *next;
-  struct callback *callout;
-  time_t when;
-};
-#endif
-
 /* GABA:
    (class
      (name io_backend)
      (vars
        ; Linked list of fds. 
        (files object lsh_fd)
+
+       ; Stack of closed files
+       ;; (closed object lsh_fd)
+       
        ; Callouts
        ;; (callouts object callout)
        ))
@@ -320,38 +276,43 @@ void io_set_nonblocking(int fd);
 void io_set_close_on_exec(int fd);
 void io_init_fd(int fd);
 
-struct io_fd *make_io_fd(struct io_backend *b,
-			 int fd,
-			 struct exception_handler *e);
+struct lsh_fd *make_lsh_fd(struct io_backend *b,
+			   int fd,
+			   struct exception_handler *e);
 
 struct exception_handler *
 make_exc_finish_read_handler(struct lsh_fd *fd,
 			     struct exception_handler *parent,
 			     const char *context);
 
-struct connect_fd *
+struct lsh_fd *
 io_connect(struct io_backend *b,
 	   struct sockaddr_in *remote,
 	   struct sockaddr_in *local,
-	   struct fd_callback *f,
+	   struct command_continuation *c,
 	   struct exception_handler *e);
 
-struct listen_fd *
+struct lsh_fd *
 io_listen(struct io_backend *b,
 	  struct sockaddr_in *local,
-	  struct fd_listen_callback *callback,
+	  struct io_callback *callback,
 	  struct exception_handler *e);
 
-struct io_fd *io_read_write(struct io_fd *fd,
-			    struct io_read_callback *read,
-			    UINT32 block_size,
-			    struct close_callback *close_callback);
+struct io_callback *
+make_listen_callback(struct io_backend *backend,
+		     struct command_continuation *c,
+		     struct exception_handler *e);
 
-struct io_fd *io_read(struct io_fd *fd,
-		      struct io_read_callback *read,
-		      struct close_callback *close_callback);
+struct lsh_fd *io_read_write(struct lsh_fd *fd,
+			     struct io_callback *read,
+			     UINT32 block_size,
+			     struct close_callback *close_callback);
 
-struct io_fd *io_write(struct io_fd *fd,
+struct lsh_fd *io_read(struct lsh_fd *fd,
+		       struct io_callback *read,
+		       struct close_callback *close_callback);
+
+struct lsh_fd *io_write(struct lsh_fd *fd,
 		       UINT32 block_size,
 		       struct close_callback *close_callback);
 
@@ -364,14 +325,14 @@ void close_fd(struct lsh_fd *fd, int reason);
  * is completely written. */
 void close_fd_nicely(struct lsh_fd *fd, int reason);
 
-struct io_fd *io_write_file(struct io_backend *backend,
+struct lsh_fd *io_write_file(struct io_backend *backend,
 			    const char *fname, int flags,
 			    int mode,
 			    UINT32 block_size,
 			    struct close_callback *c,
 			    struct exception_handler *e);
 
-struct io_fd *
+struct lsh_fd *
 io_read_file(struct io_backend *backend,
 	     const char *fname, 
 	     struct exception_handler *e);
