@@ -2,7 +2,7 @@
  *
  *
  *
- * $Id: keyexchange.h,v 1.40 1999/12/07 22:04:02 nisse Exp $ */
+ * $Id: keyexchange.h,v 1.41 1999/12/12 19:34:03 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -138,17 +138,6 @@
        ;; (compression_server_to_client object compression_algorithm)
        ))
 */
-
-#if 0
-/* FIXME: I'm considering renaming this type to simply "keypair" */ 
-/* ;; GABA:
-   (class
-     (name keypair_info)
-     (vars
-       (public string)
-       (private object signer)))
-*/
-#endif
      
 struct lsh_string *format_kex(struct kexinit *kex);
 void disconnect_kex_failed(struct ssh_connection *connection, const char *msg);
@@ -196,11 +185,6 @@ struct install_keys *
 make_install_new_keys(int is_server,
 		      struct object_list *algorithms);
 
-#if 0
-struct keypair_info *make_keypair_info(struct lsh_string *public,
-				       struct signer *private);
-#endif
-
 struct hash_instance *
 kex_build_secret(struct hash_algorithm *H,
 		 struct lsh_string *exchange_hash,
