@@ -2,7 +2,7 @@
  *
  * Lookup signature verifiers of a public key
  *
- * $Id: lookup_verifier.h,v 1.5 2000/02/22 20:42:45 nisse Exp $ */
+ * $Id: lookup_verifier.h,v 1.6 2000/04/02 19:33:25 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -49,7 +49,7 @@
      (vars
        (lookup method (object verifier)
                       "int method"
-                      "struct user *user"
+                      "struct lsh_user *user"
 		      "struct lsh_string *key")))
 */
 
