@@ -1,6 +1,6 @@
 /* lsh_types.h
  *
- * $Id: lsh_types.h,v 1.37 2000/02/05 17:16:54 nisse Exp $ */
+ * $Id: lsh_types.h,v 1.38 2000/02/26 22:43:59 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -121,6 +121,17 @@ do {						\
   (p)[3] = (i) & 0xff;				\
 } while(0)
 
+/* Same, for 16-bit quantities */
+#define READ_UINT16(p)				\
+((((UINT32) (p)[0]) << 16)			\
+ | ((UINT32) (p)[1]))
+
+#define WRITE_UINT16(p, i)			\
+do {						\
+  (p)[0] = ((i) >> 8) & 0xff;			\
+  (p)[1] = (i) & 0xff;				\
+} while(0)
+
 /* Useful macros. */
 #define MIN(a, b) (((a)>(b)) ? (b) : (a))
 #define MAX(a, b) (((a)<(b)) ? (b) : (a))
