@@ -2,7 +2,7 @@
  *
  * main server program.
  *
- * $Id: lshd.c,v 1.84 2000/03/14 21:02:18 nisse Exp $ */
+ * $Id: lshd.c,v 1.85 2000/04/11 20:31:48 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -387,6 +387,10 @@ main_argp_parser(int key, char *arg, struct argp_state *state)
     case OPT_NO_PUBLICKEY:
       self->with_publickey = 0;
       break;
+
+    case OPT_ROOT_LOGIN:
+      self->allow_root = 1;
+      break;
       
 #if WITH_TCP_FORWARD
     case OPT_TCPIP_FORWARD:
