@@ -2,7 +2,7 @@
  *
  * Reads a sexp in given form from, and writes it in given form.
  *
- * $Id: sexp_conv.c,v 1.13 2000/02/06 18:55:17 nisse Exp $ */
+ * $Id: sexp_conv.c,v 1.14 2000/02/22 21:46:05 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -32,6 +32,7 @@
 #include "lsh_argp.h"
 #include "sexp_commands.h"
 #include "spki.h"
+#include "version.h"
 #include "werror.h"
 #include "xalloc.h"
 
@@ -90,6 +91,11 @@ do_exc_sexp_conv_handler(struct exception_handler *self,
 
 /* Option parsing */
 
+const char *argp_program_version
+= "sexp_conv-" VERSION;
+
+const char *argp_program_bug_address = BUG_ADDRESS;
+
 #define OPT_HASH 0x200
 #define OPT_SPKI_HASH 0x201
 #define OPT_RAW_HASH 0x202
