@@ -1,6 +1,6 @@
 /* userauth.h
  *
- * $Id: userauth.h,v 1.20 2000/03/07 23:30:19 nisse Exp $
+ * $Id: userauth.h,v 1.21 2000/04/02 18:55:27 nisse Exp $
  */
 
 /* lsh, an implementation of the ssh protocol
@@ -58,7 +58,7 @@ make_userauth_special_exception(struct lsh_string *reply,
 
 /* GABA:
    (class
-     (name user)
+     (name lsh_user)
      (vars
        ; This string include a terminating NUL-character, for
        ; compatibility with library and system calls.
